{% spaceless %}
    <style>
        table.ajax_list>thead>tr>th.ajax_list_sorter {
            background-image: url({{ sort_icon_default|safe }});
        }
        table.ajax_list>thead>tr>th.ajax_list_sorter.ajax_list_sorter_asc {
            background-image: url({{ sort_icon_asc|safe }});
        }
        table.ajax_list>thead>tr>th.ajax_list_sorter.ajax_list_sorter_desc {
            background-image: url({{ sort_icon_desc|safe }});
        }
    </style>
    <table {% for attr_name, attr_value in table_attrs.items %}{{ attr_name }}='{{ attr_value }}' {% endfor %}>
        {{ thead|safe }}
        {{ tfoot|safe }}
        {{ tbody|safe }}
    </table>
{% endspaceless %}