/* TABLE HEAD */

table.ajax_list>thead>tr>th {
    text-align: center;
    border-left: solid 1px white !important;
}

table.ajax_list>thead>tr>th.ajax_list_sorter {
    background-repeat: no-repeat;
    background-attachment: scroll;
    background-position: right center;
    cursor: pointer; 
}


/* TABLE FOOT */

table.ajax_list tfoot tr td.ajax_list_pagination_cell, table.ajax_list tfoot tr td.ajax_list_records_count_cell {
    text-align: center;
}

table.ajax_list tfoot tr td.ajax_list_pagination_cell span.ajax_list_page {
    margin-left: 5px;
    margin-right: 5px;
    cursor: pointer;
}

table.ajax_list tfoot tr td.ajax_list_pagination_cell span.current_page_display {
    margin-left: 5px;
    margin-right: 5px;
}