{% spaceless %}
{% load i18n%}

{% if page.object_list %}
    <tfoot>
        <tr>
            <td class='ajax_list_pagination_cell' colspan='{{ fields_count }}'>
                {% if page.has_previous %}
                    <span class='ajax_list_page' data-page-number='1' title='{% trans "First" %}'>
                        <span>&lt;&lt;</span>
                    </span>
                    <span class='ajax_list_page' data-page-number='{{ page.previous_page_number }}' title='{% trans "Previous" %}'>
                        <span>&lt;</span>
                    </span>
                {% endif %}
                
                <span class='current_page_display'>{% trans "Page" %} {{ page.number }} {% trans "of" %} {{ page.paginator.num_pages }}</span>
                <input type='hidden' class='current_page' value='{{ page.number }}' />
                
                {% if page.has_next %}
                    <span class='ajax_list_page' data-page-number='{{ page.next_page_number }}' title='{% trans "Next" %}'>
                        <span>&gt;</span>
                    </span>
                    <span class='ajax_list_page' data-page-number='{{ page.paginator.page_range|last }}' title='{% trans "Last" %}'>
                        <span>&gt;&gt;</span>
                    </span>
                {% endif %}
            </td>
        </tr>
        {% if show_records_count %}
            <tr>
                <td class='ajax_list_records_count_cell' colspan='{{ fields_count }}'>
                    <span class='current_records_display'>{% trans "Records" %} {{ page.start_index }}~{{ page.end_index }} {% trans "of" %} {{ page.paginator.count }}</span>
                </td>
            </tr>
        {% endif %}
    </tfoot>
{% endif %}

{% endspaceless %}
