# -*- coding: utf-8 -*-

from setuptools import setup


setup(
    name = 'django-ajax-model-listing',
    version = '0.1.5',
    author = 'Victor Oliveira da Silva',
    author_email = 'victor_o_silva@hotmail.com',
    packages = ['ajax_model_listing'],
    include_package_data = True,
    url = 'http://pypi.python.org/pypi/django-ajax-model-listing/',
    license = 'Creative Commons Attribution-Noncommercial-Share Alike license',
    description = "Ajax-based model listing for Django. Supports pagination, sorting and filtering. Needs jQuery. Docs coming soon. Demo project here: https://bitbucket.org/victorsilv4/django_ajax_model_listing_demos",
)

